Module error

Module error 

pub mod error Module containing all custom error types. All type shall implement Error.

Enums

CheckTargetError
Custom error type for a failed attempt to check the availability of a Target.
ParseTargetError
Custom error type for a failed attempt to parse something into a Target.
ResolveTargetError
Custom error type for a failed attempt to resolve a Target.

Type Aliases

ErrorMessage
Alias for preallocated error messages