pub mod error Module containing all custom error types. All type shall implement Error.
Enums
- Check
Target Error - Custom error type for a failed attempt to check the availability of a Target.
- Parse
Target Error - Custom error type for a failed attempt to parse something into a Target.
- Resolve
Target Error - Custom error type for a failed attempt to resolve a Target.
Type Aliases
- Error
Message - Alias for preallocated error messages